@@ -62,7 +62,7 @@ copyright = '2011, Agendaless Consulting <chrism@plope.com>'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.9.4'
+version = '0.9.5'
 # The full version, including alpha/beta/rc tags.
 release = version
 
@@ -105,7 +105,7 @@ pygments_style = 'sphinx'
 sys.path.append(os.path.abspath('_themes'))
 html_theme_path = ['_themes']
 html_theme = 'pyramid'
-html_theme_options = dict(github_url='http://github.com/Pylons/pyramid_debugtoolbar')
+html_theme_options = dict(github_url='https://github.com/Pylons/pyramid_debugtoolbar')
 
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
