@@ -1,4 +1,3 @@
-from pyramid.encode import url_quote
 from pyramid.settings import asbool
 from pyramid_debugtoolbar.utils import as_globals_list
 from pyramid_debugtoolbar.utils import as_list
@@ -20,6 +19,7 @@ default_panel_names = (
     'pyramid_debugtoolbar.panels.performance.PerformanceDebugPanel',
     'pyramid_debugtoolbar.panels.routes.RoutesDebugPanel',
     'pyramid_debugtoolbar.panels.sqla.SQLADebugPanel',
+    'pyramid_debugtoolbar.panels.tweens.TweensDebugPanel',
     )
 
 default_hosts = ('127.0.0.1', '::1')
@@ -48,9 +48,8 @@ def includeme(config):
     directly. """
     settings = parse_settings(config.registry.settings)
     config.registry.settings.update(settings)
-    config.include('pyramid_jinja2')
-    j2_env = config.get_jinja2_environment()
-    j2_env.filters['urlencode'] = url_quote
+    if not 'mako.directories' in config.registry.settings:
+        config.registry.settings['mako.directories'] = []
     config.add_static_view('_debug_toolbar/static', STATIC_PATH)
     config.add_tween('pyramid_debugtoolbar.toolbar_tween_factory')
     config.add_subscriber(
