@@ -1,3 +1,5 @@
+from pprint import saferepr
+
 from pyramid_debugtoolbar.panels import DebugPanel
 from pyramid_debugtoolbar.utils import dictrepr
 
@@ -31,7 +33,8 @@ class RequestVarsDebugPanel(DebugPanel):
             attr_dict['response'] = repr(attr_dict['response'])
         vars.update({
             'get': [(k, request.GET.getall(k)) for k in request.GET],
-            'post': [(k, request.POST.getall(k)) for k in request.POST],
+            'post': [(k, [saferepr(p) for p in request.POST.getall(k)])
+                    for k in request.POST],
             'cookies': [(k, request.cookies.get(k)) for k in request.cookies],
             'attrs': dictrepr(attr_dict),
             'environ': dictrepr(request.environ),
@@ -42,6 +45,6 @@ class RequestVarsDebugPanel(DebugPanel):
             })
 
         return self.render(
-            'pyramid_debugtoolbar.panels:templates/request_vars.jinja2',
+            'pyramid_debugtoolbar.panels:templates/request_vars.mako',
             vars,
             request=self.request)
